@@ -1,6 +1,7 @@
 """Code for flask app"""
 import logging
 import os
+from datetime import timedelta
 
 import coloredlogs
 from flask import Flask, current_app, redirect, request, url_for
@@ -8,6 +9,7 @@ from flask_babel import Babel
 from flask_cors import CORS
 from flask_login import current_user
 from flaskext.markdown import Markdown
+from markupsafe import Markup
 
 from . import extensions
 from .blueprints import (
@@ -48,6 +50,7 @@ except ImportError:
 
 def create_app(config_file=None, config=None):
     """Flask app factory function."""
+
     app = Flask(__name__)
     CORS(app)
     app.jinja_env.add_extension("jinja2.ext.do")
@@ -60,6 +63,12 @@ def create_app(config_file=None, config=None):
     if config_file:  # Params from an optional .py config file provided by the user
         app.config.from_pyfile(config_file)
 
+    session_timeout_minutes = app.config.get("SESSION_TIMEOUT_MINUTES")
+    if session_timeout_minutes:
+        session_duration = timedelta(minutes=session_timeout_minutes)
+        app.config["PERMANENT_SESSION_LIFETIME"] = session_duration
+        app.config["REMEMBER_COOKIE_DURATION"] = session_duration
+
     app.config["JSON_SORT_KEYS"] = False
     current_log_level = LOG.getEffectiveLevel()
     coloredlogs.install(level="DEBUG" if app.debug else current_log_level)
@@ -95,7 +104,6 @@ def create_app(config_file=None, config=None):
 def configure_extensions(app):
     """Configure Flask extensions."""
 
-    extensions.toolbar.init_app(app)
     extensions.bootstrap.init_app(app)
     extensions.mongo.init_app(app)
     extensions.store.init_app(app)
@@ -124,9 +132,18 @@ def configure_extensions(app):
             app.config.get("MME_TOKEN"),
         ]
     ):
-        LOG.info("MatchMaker Exchange enabled")
+        LOG.info("Matchmaker Exchange extension enabled")
         extensions.matchmaker.init_app(app)
 
+    if all(
+        [
+            app.config.get("BEACON_URL"),
+            app.config.get("BEACON_TOKEN"),
+        ]
+    ):
+        LOG.info("Beacon extension enabled")
+        extensions.beacon.init_app(app)
+
     if app.config.get("RERUNNER_API_ENTRYPOINT") and app.config.get("RERUNNER_API_KEY"):
         LOG.info("Rerunner service enabled")
         # setup rerunner service
@@ -281,7 +298,7 @@ def configure_coverage(app):
         accept_languages = current_app.config.get("ACCEPT_LANGUAGES", ["en"])
 
         # first check request args
-        session_language = request.args.get("lang")
+        session_language = Markup.escape(request.args.get("lang"))
         if session_language in accept_languages:
             current_app.logger.info("using session language: %s", session_language)
             return session_language
