@@ -16,6 +16,7 @@ from requests.auth import HTTPBasicAuth
 from xlsxwriter import Workbook
 
 from scout.constants import (
+    CALLERS,
     CANCER_PHENOTYPE_MAP,
     CASE_REPORT_CASE_FEATURES,
     CASE_REPORT_CASE_IND_FEATURES,
@@ -41,7 +42,7 @@ from scout.parse.matchmaker import genomic_features, hpo_terms, omim_terms, pars
 from scout.server.blueprints.variant.controllers import variant as variant_decorator
 from scout.server.blueprints.variants.controllers import get_manual_assessments
 from scout.server.extensions import RerunnerError, gens, matchmaker, rerunner, store
-from scout.server.utils import institute_and_case
+from scout.server.utils import case_has_alignments, case_has_mt_alignments, institute_and_case
 from scout.utils.scout_requests import delete_request_json, post_request_json
 
 LOG = logging.getLogger(__name__)
@@ -102,6 +103,27 @@ def coverage_report_contents(base_url, institute_obj, case_obj):
     return html_body_content
 
 
+def _populate_case_groups(store, case_obj, case_groups, case_group_label):
+    """Case groups allow display of information about user linked cases together on one case.
+    Notably variantS lists show shared annotations and alignment views show all alignments
+    available for the group.
+
+    Each case may belong to any of a list of groups. Groups have human readable labels
+    that need to be fetched separately. Alignments for each case, that belongs to
+    a group that the present case also belongs to, are added to the present case.
+
+    Args:
+         store(adapter.MongoAdapter)
+         case_obj(models.Case)
+         case_group(dict) - keys group ids, values list(case_ids)
+         case_group_label(dict) - keys group ids, values case_group_labels(str)
+    """
+    if case_obj.get("group"):
+        for group in case_obj.get("group"):
+            case_groups[group] = list(store.cases(group=group))
+            case_group_label[group] = store.case_group_label(group)
+
+
 def case(store, institute_obj, case_obj):
     """Preprocess a single case.
 
@@ -134,13 +156,13 @@ def case(store, institute_obj, case_obj):
 
     case_obj["assignees"] = [store.user(user_email) for user_email in case_obj.get("assignees", [])]
 
-    # Fetch ids for grouped cases
+    # Provide basic info on alignment files availability for this case
+    case_has_alignments(case_obj)
+    case_has_mt_alignments(case_obj)
+
     case_groups = {}
     case_group_label = {}
-    if case_obj.get("group"):
-        for group in case_obj.get("group"):
-            case_groups[group] = list(store.cases(group=group))
-            case_group_label[group] = store.case_group_label(group)
+    _populate_case_groups(store, case_obj, case_groups, case_group_label)
 
     # Fetch the variant objects for suspects and causatives
     suspects = [
@@ -403,6 +425,10 @@ def case_report_variants(store, case_obj, institute_obj, data):
             for feat in VARIANT_REPORT_VARIANT_FEATURES:
                 filtered_var_obj[feat] = var_obj.get(feat)
 
+            variant_category = var_obj["category"]
+
+            populate_individual_callers(filtered_var_obj, var_obj)
+
             decorated_info = variant_decorator(
                 store=store,
                 institute_id=institute_obj["_id"],
@@ -412,7 +438,7 @@ def case_report_variants(store, case_obj, institute_obj, data):
                 add_case=False,
                 add_other=False,
                 get_overlapping=False,
-                variant_type=var_obj["category"],
+                variant_type=variant_category,
                 institute_obj=institute_obj,
                 case_obj=case_obj,
             )
@@ -421,6 +447,24 @@ def case_report_variants(store, case_obj, institute_obj, data):
         data["variants"][var_type] = decorated_variants
 
 
+def populate_individual_callers(filtered_var_obj, var_obj):
+    """Adds caller status for variant, for export/filtering.
+    Uses the CALLERS constant to copy fields appropriate for the variant category
+    from the rich store variant to the filtered display variant object.
+
+    Args:
+        filtered_var_obj: variant object to be exported/displayed
+        rich_var_obj: original richer variant object recently fetched from store
+
+    """
+    variant_category = var_obj["category"]
+    for var_cat, var_callers in CALLERS.items():
+        if var_cat == variant_category:
+            for caller in var_callers:
+                caller_id = caller.get("id")
+                filtered_var_obj[caller_id] = var_obj.get(caller_id)
+
+
 def case_report_content(store, institute_id, case_name):
     """Gather contents to be visualized in a case report
 
@@ -963,132 +1007,6 @@ def multiqc(store, institute_id, case_name):
     return dict(institute=institute_obj, case=case_obj)
 
 
-def prepare_beacon_req_params():
-    """Prepares URL and Headers for sending a request to the beacon server.
-
-    Returns:
-        url, headers(tuple)
-    """
-    req_url = current_app.config.get("BEACON_URL")
-    beacon_token = current_app.config.get("BEACON_TOKEN")
-    if not req_url or not beacon_token:
-        return
-    req_headers = JSON_HEADERS
-    req_headers["X-Auth-Token"] = beacon_token
-    return req_url, req_headers
-
-
-def beacon_remove(case_id):
-    """Remove all variants from a case in Beacon by handling a POST request to the /apiv1.0/delete Beacon endpoint.
-
-    Args:
-        case_id(str): A case _id
-
-    """
-    if prepare_beacon_req_params() is None:
-        flash(
-            "Please check config file. It should contain both BEACON_URL and BEACON_TOKEN",
-            "warning",
-        )
-        return
-    request_url, req_headers = prepare_beacon_req_params()
-
-    case_obj = store.case(case_id=case_id)
-    beacon_submission = case_obj.get("beacon")
-
-    if beacon_submission is None:
-        flash("Couldn't find a valid beacon submission for this case", "warning")
-        return
-
-    # Prepare beacon request data
-    assembly = "GRCh37" if "37" in str(case_obj["genome_build"]) else "GRCh38"
-    dataset_id = "_".join([case_obj["owner"], assembly])
-    samples = [sample for sample in beacon_submission.get("samples", [])]
-    data = {"dataset_id": dataset_id, "samples": samples}
-    resp = delete_request_json("/".join([request_url, "delete"]), req_headers, data)
-    flash_color = "success"
-    message = resp.get("content", {}).get("message")
-    if resp.get("status_code") == 200:
-        store.case_collection.update_one({"_id": case_obj["_id"]}, {"$unset": {"beacon": 1}})
-    else:
-        flash_color = "warning"
-    flash(f"Beacon responded:{message}", flash_color)
-
-
-def beacon_add(form):
-    """Save variants from one or more case samples to the Beacon server.
-       Handle a POST request to the /apiv1.0/add Beacon endpoint
-
-    Args:
-        form(werkzeug.datastructures.ImmutableMultiDict): beacon submission form
-
-    """
-    if prepare_beacon_req_params() is None:
-        flash(
-            "Please check config file. It should contain both BEACON_URL and BEACON_TOKEN",
-            "warning",
-        )
-        return
-    request_url, req_headers = prepare_beacon_req_params()
-
-    case_obj = store.case(case_id=form.get("case"))
-    # define case individuals (individual_id, same as in VCF) to filter VCF files with
-    individuals = []
-    if form.get("samples") == "affected":
-        individuals = [
-            ind["individual_id"] for ind in case_obj["individuals"] if ind["phenotype"] == 2
-        ]
-    else:
-        individuals = [ind["individual_id"] for ind in case_obj["individuals"]]
-
-    # define genes to filter VCF files with
-    gene_filter = set()
-    for panel in form.getlist("panels"):
-        gene_filter.update(store.panel_to_genes(panel_id=panel, gene_format="hgnc_id"))
-    gene_filter = list(gene_filter)
-
-    submission = {
-        "created_at": datetime.datetime.now(),
-        "user": current_user.email,
-        "samples": individuals,
-        "panels": form.getlist("panels"),
-        "vcf_files": [],
-    }
-
-    # Prepare beacon request data
-    assembly = "GRCh37" if "37" in str(case_obj["genome_build"]) else "GRCh38"
-    data = {
-        "dataset_id": "_".join([case_obj["owner"], assembly]),
-        "samples": individuals,
-        "assemblyId": assembly,
-    }
-    if gene_filter:  # Gene filter is not mandatory
-        data["genes"] = {"ids": gene_filter, "id_type": "HGNC"}
-
-    # loop over selected VCF files and send an add request to Beacon for each one of them
-    vcf_files = form.getlist("vcf_files")
-    if not vcf_files:
-        flash("Please select at least one VCF file to save to Beacon", "warning")
-        return
-    for vcf_key in form.getlist("vcf_files"):
-        data["vcf_path"] = case_obj["vcf_files"].get(vcf_key)
-        resp = post_request_json("/".join([request_url, "add"]), data, req_headers)
-        if resp.get("status_code") != 200:
-            flash(f"Beacon responded:{resp.get('content',{}).get('message')}", "warning")
-            continue
-        submission["vcf_files"].append(vcf_key)
-
-    if len(submission["vcf_files"]) > 0:
-        flash(
-            f"Variants from the following files are going to be saved to Beacon:{submission['vcf_files']}",
-            "success",
-        )
-        store.case_collection.find_one_and_update(
-            {"_id": case_obj["_id"]}, {"$set": {"beacon": submission}}
-        )
-    return
-
-
 def matchmaker_check_requirements(request):
     """Make sure requirements are fulfilled before submitting any request to MatchMaker Exchange
 
