@@ -17,11 +17,10 @@ from flask import (
 from flask_login import current_user
 from werkzeug.datastructures import Headers
 
-from scout.constants import CASEDATA_HEADER, CLINVAR_HEADER
+from scout.constants import CASEDATA_HEADER, CLINVAR_HEADER, VERBS_ICONS_MAP, VERBS_MAP
 from scout.server.blueprints.variants.controllers import update_form_hgnc_symbols
 from scout.server.extensions import beacon, loqusdb, store
 from scout.server.utils import institute_and_case, jsonconverter, templated
-from scout.utils.scout_requests import post_request_json
 
 from . import controllers
 from .forms import GeneVariantFiltersForm, InstituteForm, PhenoModelForm, PhenoSubPanelForm
@@ -37,6 +36,15 @@ blueprint = Blueprint(
 )
 
 
+@blueprint.route("/overview/timeline", methods=["GET"])
+@templated("overview/timeline.html")
+def timeline():
+    data = {"events": controllers.get_timeline_data(request.args.get("limit") or "50")}
+    data["verbs_map"] = VERBS_MAP
+    data["verbs_icons"] = VERBS_ICONS_MAP
+    return dict(**data)
+
+
 @blueprint.route("/api/v1/institutes", methods=["GET"])
 def api_institutes():
     """API endpoint that returns institutes data"""
